@@ -2,6 +2,8 @@
 import socket
 import time
 import struct
+import requests
+import logging
 
 PT_ACTION = 0x0A
 PT_HELO = 0x01
@@ -12,19 +14,54 @@ ACTION_EXECBUILTIN = b"\1"
 
 class EventClient:
     def __init__(self, api_host,
-                       api_port=9777):
+                       api_udp_port=9777,
+                       api_http_port=8080
+                       ):
         """event client class"""
         self.api_host = api_host
-        self.api_port = api_port
+        self.api_udp_port = api_udp_port
+        self.api_http_port = api_http_port
 
         self.api_token = int(time.time())
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         self.sock.bind(('0.0.0.0', 1444))
 
-        self.send_helo()
+        self.start_client()
+
+    def start_client(self):
+        """start client only if kodi is ready"""
+        logging.debug("Checking if the backend is online...")
+
+        timeout_max = 120
+        timeout_raised = False
+        kodi_ready = False
+        start_time = time.time()
+        p = {"method": "JSONRPC.Ping", "id": 1, "jsonrpc": "2.0"}
+        api_url = "http://%s:%s/jsonrpc" % (self.api_host, self.api_http_port)
+
+        while (not kodi_ready) and (not timeout_raised):
+            if (time.time() - start_time) >= timeout_max:
+                timeout_raised = True
+            else:
+                try:
+                    # send ping to kodi jsonrpc api
+                    r = requests.post(url=api_url, json=p)
+                    logging.debug("Backend response: %s" % r.json())
+                    kodi_ready = True
+                except requests.exceptions.ConnectionError:
+                    pass
+                    time.sleep(10)
+
+        if timeout_raised:
+            raise Exception( "Backend api not ready ?" )
+
+        if kodi_ready:
+            logging.debug("Backend is ready")
+            self.send_helo()
 
     def refresh_connection(self):
         """refresh token"""
+        logging.debug("Refresh udp connection")
         self.api_token = int(time.time())
         self.send_helo()
 
@@ -48,11 +85,13 @@ class EventClient:
 
     def send_packet(self, pkt):  
         """connect to event servers and send packet"""
-        addr = (self.api_host, self.api_port)
+        addr = (self.api_host, self.api_udp_port)
         self.sock.sendto(pkt, addr)
 
     def send_helo(self):
         """send helo packet"""
+        logging.debug("Sending helo packet")
+
         device_name = b"REMOTECONTROL" + b"\0"
         icon_type = b"\0"
         port_no = 0
@@ -68,11 +107,15 @@ class EventClient:
 
     def send_bye(self):
         """send bye packet"""
+        logging.debug("Sending bye packet")
+
         pkt = self.get_header(psize=0, ptype=PT_BYE)
         self.send_packet(pkt=pkt)
 
     def send_ping(self):
         """send ping packet"""
+        logging.debug("Sending ping packet")
+
         pkt = self.get_header(psize=0, ptype=PT_PING)
         self.send_packet(pkt=pkt)
 
@@ -81,6 +124,8 @@ class EventClient:
         https://kodi.wiki/view/Action_IDs
         https://kodi.wiki/view/List_of_built-in_functions
         """
+        logging.debug("Sending action packet")
+
         pkt_action = ACTION_EXECBUILTIN + msg.encode() + b"\0"
         pkt_header = self.get_header(psize=len(pkt_action),
                                      ptype=PT_ACTION)
